@@ -24,10 +24,15 @@ import theano.tensor as tt
 
 import pymc3 as pm
 
-from ..model import Model
-from .arraystep import ArrayStepShared, Competence, metrop_select
-from .compound import CompoundStep
-from .metropolis import DEMetropolisZ, Metropolis, Proposal, delta_logp
+from pymc3.model import Model
+from pymc3.step_methods.arraystep import ArrayStepShared, Competence, metrop_select
+from pymc3.step_methods.compound import CompoundStep
+from pymc3.step_methods.metropolis import (
+    DEMetropolisZ,
+    Metropolis,
+    Proposal,
+    delta_logp,
+)
 
 __all__ = [
     "MetropolisMLDA",
@@ -328,7 +333,7 @@ class MLDA(ArrayStepShared):
         ...                       tune=100, step=step_method,
         ...                       random_seed=123)
         ...
-        ... pm.summary(trace, kind="stats")
+        ... az.summary(trace, kind="stats")
            mean     sd  hdi_3%  hdi_97%
         x  0.99  0.987  -0.734    2.992
 
@@ -351,10 +356,6 @@ class MLDA(ArrayStepShared):
     default_blocked = True
     generates_stats = True
 
-    # stat data types are different, depending on the base sampler.
-    # these are assigned in the init method.
-    stats_dtypes = None
-
     def __init__(
         self,
         coarse_models: List[Model],
@@ -666,7 +667,7 @@ class MLDA(ArrayStepShared):
 
         else:
             # otherwise, set it up from scratch.
-            self.stats_dtypes = [{"accept": np.float64, "accepted": np.bool, "tune": np.bool}]
+            self.stats_dtypes = [{"accept": np.float64, "accepted": bool, "tune": bool}]
 
             if isinstance(self.step_method_below, MetropolisMLDA):
                 self.stats_dtypes.append({"base_scaling": np.float64})
